## Loss of Inflection Database

The Loss of Inflection Database is a digital repository of examples of language change from 50 languages, each involving the loss of inflectional contrasts within paradigms. 

On our [showcase site](https://lossofinflection.surrey.ac.uk/), users may filter records by a broad range of parameters to find examples meeting particular criteria, or navigate through a timeline of changes to explore the historical development of individual languages and families.

## Citation

Sims-Williams, Helen & Matthew Baerman. 2019. Loss of Inflection Database. University of Surrey.

## Acknowledgements

The database was created for the project [Loss of Inflection](https://www.smg.surrey.ac.uk/projects/loss-of-inflection/), funded by the Arts and Humanities Research Council under grant number AH/N00163X/1. 

We are grateful to Hans-Olav Enger, Alexander Krasovitsky, Felicity Meakins, and Nina Sumbatova, for contributing their time and expertise in collecting and analysing data from Scandinavian, Slavic, Australian and Caucasian languages, and to Oliver Bond and Greville Corbett for their help with the design of the database.

## Data sources

This dataset was collated from a variety of published sources, details of which can be found in the document `csv/references.csv`.

## File structure

The dataset consists of the following files.

| Filepath | Contains information about |
|--|--|
| csv/metachanges.csv | Top-level changes to paradigm structure. |
| csv/subchanges.csv | Lower-level information about metachanges. |
| csv/features_lost.csv | Morphosyntactic features that were lost in each metachange/subchange. |
| csv/features_affected.csv | Morphosyntactic features whose expression was affected by each metachange/subchange. |
| csv/values_lost.csv | Morphosyntactic feature values that were lost in each metachange/subchange. |
| csv/values_neutralised.csv | Distinctions between morphosyntactic feature values that were neutralised in each metachange/subchange. |
| csv/values_affected.csv | Morphosyntactic feature values whose expression was affected by each metachange/subchange. |
| csv/languages.csv | Languages featured in the dataset. |
| csv/references.csv | Published data sources. |
| images | image files referred to in `csv/metachanges.csv`, illustrating changes to paradigms. |

### csv/metachanges.csv

| Column heading | Description |
|--|--|
| ID | Identifier for the metachange |
| Language | A language identifier (see `languages.csv`) |
| Wordclass | Wordclass in which the change occurred (e.g. noun) |
| Subclass | Subclass of the wordclass (e.g. an inflection class or semantic class) or None |
| Notes | Text description of the change |
| Change type | replacement/loss/neutralisation/mixed[^1] |
| Cells changed | Cells that were altered in the change, in `(feature:value)` format[^2]|
| Image before | Image filename illustrating paradigm structure before the change (excluding .png extension) |
| Image after | Image filename illustrating paradigm structure after the change (excluding .png extension) |
| Previous | Identifier of the preceding metachange, if part of a sequence, or None (if not part of a sequence, or the first change in a sequence) |
| Reference | Bibliographical identifier for source data (see `references.csv`) |

### csv/subchanges.csv

| Column heading | Description |
|--|--|
| Metachange | Identifier for the associated metachange (see `metachanges.csv`) |
| ID | Identifier for the subchange |
| Change type  | replacement/loss/neutralisation/mixed[^1] |
| Cells changed | Cells that were altered in the change, in `(feature:value)` format[^2]|
| Replacement | What replaced the forms: syntax (i.e. an alternative syntactic means of expression), new form (i.e. a new form from outside the paradigm), or an existing form in the paradigm belonging to cell(s) denoted in `(feature:value)` format[^2]|
| Sound change? | True if sound change was involved in the change, False otherwise |
| Morphological change? | True if morphological change was involved in the change, False otherwise |
| Semantic change? | True if semantic change was involved in the change, False otherwise |


### csv/features_lost.csv
| Column heading | Description |
|--|--|
| ID | Identifier for the associated subchange or metachange (see `metachanges.csv` and `subchanges.csv`))|
| Features lost | Feature(s) lost in the change |
| Morphological context | The subparadigm in which the feature(s) were lost, in `(feature:value)` format.[^2] If this field is empty, the feature(s) were lost throughout the paradigm.|
| Other restriction(s) | Any other semantic or syntactic restrictions (e.g. attributive adjectives; habitual sense of the imperfect...), or None|


### csv/features_affected.csv
| Column heading | Description |
|--|--|
| ID | Identifier for the associated subchange or metachange (see `metachanges.csv` and `subchanges.csv`))|
| Features affected | Feature whose expression was affected by the change |
| Morphological context | The subparadigm in which the feature was affected, in `(feature:value)` format.[^2] If this field is empty, the feature(s) were lost throughout the paradigm.|
| Other restriction(s) | Any other semantic or syntactic restrictions (e.g. attributive adjectives; habitual sense of the imperfect...), or None|

### csv/values_lost.csv
| Column heading | Description |
|--|--|
| ID | Identifier for the associated subchange or metachange (see `metachanges.csv` and `subchanges.csv`))|
| Values lost | Value lost in the change |
| Morphological context | The subparadigm in which the value was lost, in `(feature:value)` format.[^2] If this field is empty, the feature(s) were lost throughout the paradigm.|
| Other restriction(s) | Any other semantic or syntactic restrictions (e.g. attributive adjectives; habitual sense of the imperfect...), or None|

### csv/values_neutralised.csv
| Column heading | Description |
|--|--|
| ID | Identifier for the associated subchange or metachange (see `metachanges.csv` and `subchanges.csv`))|
| Values neutralised | Values of the same feature which were previously expressed with distinct forms, but the distinction between them was neutralised in the change. |
| Morphological context | The subparadigm in which the values were neutralised, in `(feature:value)` format.[^2] If this field is empty, the feature(s) were lost throughout the paradigm.|
| Other restriction(s) | Any other semantic or syntactic restrictions (e.g. attributive adjectives; habitual sense of the imperfect...), or None|

### csv/values_affected.csv
| Column heading | Description |
|--|--|
| ID | Identifier for the associated subchange or metachange (see `metachanges.csv` and `subchanges.csv`))|
| Values affected | Value whose expression was affected by the change |
| Morphological context | The subparadigm in which the values were affected, in `(feature:value)` format.[^2] If this field is empty, the feature(s) were lost throughout the paradigm.|
| Other restriction(s) | Any other semantic or syntactic restrictions (e.g. attributive adjectives; habitual sense of the imperfect...), or None|

### csv/languages.csv
| Column heading | Description |
|--|--|
| Language | Language identifier |
| Family | Top-level language family|
| Subfamily | Branch of the language family |
| Area | Broad area in which the language is predominantly spoken |

### csv/references.csv
| Column heading | Description |
|--|--|
| Short | Bibliographical identifier (author surname and year of publication)|
| Long | Full reference in APA format |

### images
Folder containing image files in .png format, illustrating paradigm structure before and after metachanges. Filenames are referenced in `Image before` and `Image after` columns of `metachanges.csv`.

[^1] See Sims-Williams, Helen, & Baerman, Matthew (2021). A typological perspective on the loss of inflection. In Kranich, Svenja and Breban, Tine (eds.), _Lost in change: Causes and processes in the loss of grammatical elements and constructions_, 21-49.

[^2] In this format, multiple feature:value specifications within a single parenthesis should be understood as connected by AND. For example, `(number:singular case:nominative)` refers to all nominative singular cells. Multiple parentheses should be understood as connected by OR, e.g. `(number:singular)(case:nominative)` refers to all singular _and_ all nominative cells (including e.g. accusative singular, nominative plural, etc.)
